@@ -184,6 +184,33 @@ clutter_gdk_handle_event (GdkEvent *gdk_event)
                     event->button.y);
       break;
 
+    case GDK_TOUCH_BEGIN:
+    case GDK_TOUCH_END:
+    case GDK_TOUCH_CANCEL:
+    case GDK_TOUCH_UPDATE:
+      event = clutter_event_new (gdk_event->type == GDK_TOUCH_BEGIN ?
+                                 CLUTTER_TOUCH_BEGIN :
+                                 ((gdk_event->type == GDK_TOUCH_END) ?
+                                  CLUTTER_TOUCH_END :
+                                  (gdk_event->type == GDK_TOUCH_UPDATE ?
+                                   CLUTTER_TOUCH_UPDATE :
+                                   CLUTTER_TOUCH_CANCEL)));
+      event->touch.time = gdk_event->touch.time;
+      event->touch.x = gdk_event->touch.x;
+      event->touch.y = gdk_event->touch.y;
+      event->touch.sequence = (ClutterEventSequence *) gdk_event->touch.sequence;
+      event->touch.modifier_state = gdk_event->touch.state;
+      clutter_event_set_device (event, device);
+      clutter_event_set_source_device (event, source_device);
+      CLUTTER_NOTE (EVENT, "Touch %p %s [%",
+                    event->touch.sequence,
+                    event->type == CLUTTER_TOUCH_BEGIN ? "begin" :
+                    (event->type == CLUTTER_TOUCH_END ? "end" :
+                     (event->type == CLUTTER_TOUCH_UPDATE ? "update"
+                      : "cancel")),
+                    event->touch.x, event->touch.y);
+      break;
+
     case GDK_2BUTTON_PRESS:
     case GDK_3BUTTON_PRESS:
       /* these are handled by clutter-main.c updating click_count */
@@ -221,7 +248,10 @@ clutter_gdk_handle_event (GdkEvent *gdk_event)
       clutter_event_set_source_device (event, source_device);
       if (gdk_event->type == GDK_ENTER_NOTIFY)
         _clutter_input_device_set_stage (clutter_event_get_device (event), stage);
-      else
+      else if (gdk_event->type == GDK_LEAVE_NOTIFY &&
+               gdk_event->crossing.mode != GDK_CROSSING_TOUCH_BEGIN &&
+               gdk_event->crossing.mode != GDK_CROSSING_TOUCH_END &&
+               gdk_event->crossing.mode != GDK_CROSSING_DEVICE_SWITCH)
         _clutter_input_device_set_stage (clutter_event_get_device (event), NULL);
       CLUTTER_NOTE (EVENT, "Crossing %s [%.2f, %.2f]",
                     event->type == CLUTTER_ENTER ? "enter" : "leave",
@@ -242,8 +272,8 @@ clutter_gdk_handle_event (GdkEvent *gdk_event)
 
         clutter_actor_get_size (CLUTTER_ACTOR (stage), &w, &h);
 
-        if (w != gdk_event->configure.width ||
-            h != gdk_event->configure.height)
+        if ((int) w != gdk_event->configure.width ||
+            (int) h != gdk_event->configure.height)
           {
             clutter_actor_set_size (CLUTTER_ACTOR (stage),
                                     gdk_event->configure.width,
